==> paraview-v0.6.0.zip: paraview-v0.6.0/ParaView/ParaView/vtkPVTraceFileDialog.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkPVTraceFileDialog.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkPVTraceFileDialog - asks the user if she wants to save the old trace
// .SECTION Description
// This is a dialog with three buttons which should normally be:
// Delete, Do Nothing, Save. Use this to ask the user whether
// he wants to save or delete an old tracefile. Invoke returns
// 0 for do nothing, 1 for delete and 2 for save.
// .SECTION See Also
// vtkPVApplication

#ifndef __vtkPVTraceFileDialog_h
#define __vtkPVTraceFileDialog_h

#include "vtkKWMessageDialog.h"

class VTK_EXPORT vtkPVTraceFileDialog : public vtkKWMessageDialog
{
public:
  static vtkPVTraceFileDialog* New();
  vtkTypeRevisionMacro(vtkPVTraceFileDialog,vtkKWMessageDialog);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Create a Tk widget
  void Create(vtkKWApplication *app, const char *args);

  // Description:
  // Sets the save flag.
  virtual void Save();

protected:
  vtkPVTraceFileDialog();
  ~vtkPVTraceFileDialog();

  vtkKWWidget     *SaveButton;
  vtkKWWidget     *SaveFrame;

private:
  vtkPVTraceFileDialog(const vtkPVTraceFileDialog&); // Not implemented
  void operator=(const vtkPVTraceFileDialog&); // Not implemented
};


#endif

==> paraview-v1.0.4.zip: paraview-v1.0.4/ParaView/ParaView/vtkPVTraceFileDialog.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkPVTraceFileDialog.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkPVTraceFileDialog - asks the user if she wants to save the old trace
// .SECTION Description
// This is a dialog with three buttons which should normally be:
// Delete, Do Nothing, Save. Use this to ask the user whether
// he wants to save or delete an old tracefile. Invoke returns
// 0 for do nothing, 1 for delete and 2 for save.
// .SECTION See Also
// vtkPVApplication

#ifndef __vtkPVTraceFileDialog_h
#define __vtkPVTraceFileDialog_h

#include "vtkKWMessageDialog.h"

class VTK_EXPORT vtkPVTraceFileDialog : public vtkKWMessageDialog
{
public:
  static vtkPVTraceFileDialog* New();
  vtkTypeRevisionMacro(vtkPVTraceFileDialog,vtkKWMessageDialog);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Create a Tk widget
  virtual void Create(vtkKWApplication *app, const char *args);

  // Description:
  // Sets the save flag.
  virtual void Save();

protected:
  vtkPVTraceFileDialog();
  ~vtkPVTraceFileDialog();

  vtkKWWidget     *SaveButton;
  vtkKWWidget     *SaveFrame;

private:
  vtkPVTraceFileDialog(const vtkPVTraceFileDialog&); // Not implemented
  void operator=(const vtkPVTraceFileDialog&); // Not implemented
};


#endif
